
local config = require("Visually Filled Soul Gems.config")
local interop = require("Visually Filled Soul Gems.interop")
local log = require("Visually Filled Soul Gems.log")

--- Callback for when a new scene node is created for a reference.
--- We'll use it add a visual effect to soul gems that are filled.
--- @param e referenceSceneNodeCreatedEventData
local function onReferenceSceneNodeCreated(e)
	if (not e.reference.object.isSoulGem) then
		return
	end

	interop.setSoulEffectActive(e.reference)
end
event.register("referenceSceneNodeCreated", onReferenceSceneNodeCreated)

--- Grab the enchantment we're going to use for our plastic wrap.
local function onInitialized()
	log:info("Mod loaded with config: %s", json.encode(config, { indent = true }))
	interop.setEnchantmentEffect(config.enchantmentId)
end
event.register("initialized", onInitialized)

--- Create our MCM.
local function registerModConfig()
	local template = mwse.mcm.createTemplate({ name = "Apparence des gemmes remplies" })
	template:saveOnClose("Apparence des gemmes remplies", config)

	local pageDefault = template:createSideBarPage({ label = "Fonctionnalits" })
	pageDefault.sidebar:createInfo({ text = "Apparence des gemmes remplies v1.1\n  par NullCascade" })

	local catDefaultEffect = pageDefault:createCategory({ label = "Effet d'enchantement par dfaut" })
	do
		catDefaultEffect:createOnOffButton({
			label = "Activer l'effet visuel magique par dfaut ?",
			description = "Si cette option est active, l'effet visuel magique par dfaut sera appliqu aux gemmes spirituelles. Cette option peut tre dsactive si vous utilisez un replacer pour les gemmes spirituelles qui supporte les donnes VFSG personnalises.",
			variable = mwse.mcm.createTableVariable({ id = "useEnchantEffect", table = config }),
			callback = interop.refreshActiveSoulGems,
		})

		catDefaultEffect:createTextField({
			label = "Effet d'enchantement  utiliser :",
			description = "L'effet d'enchantement  appliquer aux gemmes spirituelles remplies.",
			variable = mwse.mcm.createTableVariable({ id = "enchantmentId", table = config }),
			callback = function(self)
				interop.setEnchantmentEffect(self.variable.value)
			end,
		})
	end

	local catDebug = pageDefault:createCategory({ label = "Dbug" })
	do
		catDebug:createDropdown({
			label = "Niveau de journalisation",
			description = "Dfinit le niveau de journalisation. Il est recommand de laisser cette valeur par dfaut.",
			options = {
				{ label = "TRACE", value = "TRACE" },
				{ label = "DEBUG", value = "DEBUG" },
				{ label = "INFO", value = "INFO" },
				{ label = "WARN", value = "WARN" },
				{ label = "ERROR", value = "ERROR" },
				{ label = "NONE", value = "NONE" },
			},
			variable = mwse.mcm.createTableVariable{ id = "logLevel", table = config },
			callback = function(self)
				log:setLogLevel(self.variable.value)
			end
		})
	end

	-- Finish up.
	template:register()
end
event.register("modConfigReady", registerModConfig)
